@@ -1,9 +1,17 @@
-bbag = function (data, factor = 2.57, label=TRUE, ...) 
+bbag = function (data, factor, label=TRUE, projmethod, ...) 
 {
     y <- t(data$y)
-    sco <- PCAproj(y, k = 2, center = median)$scores
-    tmp <- compute.bagplot(sco[, 1], sco[, 2], factor = factor, 
-        verbose = FALSE)
+	x = data$x
+	if(projmethod == "PCAproj")
+	{
+		sco <- PCAproj(y, k = 2, center = median)$scores
+	}
+	if(projmethod == "rapca")
+	{
+		sco = fdpca(x, data$y)$coeff[,2:3]
+		rownames(sco) = 1:ncol(data$y)
+	}
+    tmp <- compute.bagplot(sco[, 1], sco[, 2], factor = factor, verbose = FALSE)
     if (tmp$is.one.dim == TRUE) {
         warning("Bivariate principal component scores lie in one direction.")
     }
@@ -13,6 +21,7 @@ bbag = function (data, factor = 2.57, label=TRUE, ...)
 		
     points(sco[, 1], sco[, 2], pch = 16, cex = 0.5, col = 1)
     outliers <- as.numeric(rownames(tmp$pxy.outlier))
+	
     points(sco[outliers, 1], sco[outliers, 2], col = rainbow(length(outliers)), 
         pch = 16)
     box()
@@ -25,5 +34,3 @@ bbag = function (data, factor = 2.57, label=TRUE, ...)
         return(outliers)
     }
 }
-
-
